<p align="center">
  <img src="./notes/assets/drawio/torchcell-logo.drawio.png" />
</p>

Community: Add slack, add notes url

Packaging: Add packing <!-- ![Python application](https://github.com/mjvolk3/torchcell/actions/workflows/python_app.yaml/badge.svg) -->

Testing: ![Code Styling](https://github.com/mjvolk3/torchcell/workflows/Code%20Styling/badge.svg) [![codecov](https://codecov.io/gh/mjvolk3/torchcell/branch/main/graph/badge.svg)](https://codecov.io/gh/mjvolk3/torchcell)

